@@ -4,7 +4,7 @@
 -- Authors: Javier Guerra
 -- Copyright (c) 2006-2007 Kepler Project
 --
--- $Id: indexhandler.lua,v 1.3 2007/08/20 22:20:44 carregal Exp $
+-- $Id: indexhandler.lua,v 1.4 2007/11/27 15:57:05 carregal Exp $
 -----------------------------------------------------------------------------
 
 local function indexhandler (req, res, indexname)
@@ -12,7 +12,7 @@ local function indexhandler (req, res, indexname)
 	indexUrl = string.format ("http://%s%s", req.headers.host or "", indexUrl)
 	
 	res:add_header ("Location", indexUrl)
-	res.statusline = "HTTP/1.1 302 Found\r\n"
+	res.statusline = "HTTP/1.1 302 Found"
 	res.content = "redirect"
 
 	res:send_headers()
